# QualiCharge API client (and CLI!)

## Getting started with the CLI

`qcc` can be installed using `pip`:

```
pip install qcc
```

Get the list of commands and usage using the `--help` option:

```
qcc --help
```

## License

This work is released under the MIT License (see LICENSE).
